@@ -1,4 +1,4 @@
-/* Jeroen Ooms (2017)
+/* Jeroen Ooms (2018)
  * Bindings to vectorized image manipulations.
  * See API: https://www.imagemagick.org/Magick++/STL.html
  */
@@ -23,7 +23,7 @@ int magick_image_length(XPtrImage image){
 
 // [[Rcpp::export]]
 XPtrImage create (int len){
-  Image *image = new Image;
+  Image *image = new Image();
   if(len > 0){
     image->reserve(len);
   }
@@ -123,6 +123,11 @@ XPtrImage magick_image_copy(XPtrImage image, XPtrImage add){
   return image;
 }
 
+// [[Rcpp::export]]
+void magick_image_destroy(XPtrImage image){
+  image.release();
+}
+
 // [[Rcpp::export]]
 bool autobrewed(){
 #ifdef BUILD_AUTOBREW
